@@ -12,13 +12,6 @@
 # 2. Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-# 3. All advertising materials mentioning features or use of this
-#    software must display the following acknowledgement:
-#        This product includes software developed by the NetBSD
-#        Foundation, Inc. and its contributors.
-# 4. Neither the name of The NetBSD Foundation nor the names of its
-#    contributors may be used to endorse or promote products derived
-#    from this software without specific prior written permission.
 #
 # THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND
 # CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
@@ -329,46 +322,35 @@ require_progs_head_body()
     :
 }
 
-atf_test_case require_user_root
-require_user_root_head()
+atf_test_case require_user
+require_user_head()
 {
     atf_set "descr" "Helper test case for the t_meta_data test program"
-    atf_set "require.user" "root"
+    atf_set "require.user" "$(atf_config_get user)"
 }
-require_user_root_body()
+require_user_body()
 {
     :
 }
 
-atf_test_case require_user_root2
-require_user_root2_head()
+atf_test_case require_user2
+require_user2_head()
 {
     atf_set "descr" "Helper test case for the t_meta_data test program"
-    atf_set "require.user" "root"
+    atf_set "require.user" "$(atf_config_get user2)"
 }
-require_user_root2_body()
+require_user2_body()
 {
     :
 }
 
-atf_test_case require_user_unprivileged
-require_user_unprivileged_head()
+atf_test_case require_user3
+require_user3_head()
 {
     atf_set "descr" "Helper test case for the t_meta_data test program"
-    atf_set "require.user" "unprivileged"
+    atf_set "require.user" "$(atf_config_get user3)"
 }
-require_user_unprivileged_body()
-{
-    :
-}
-
-atf_test_case require_user_unprivileged2
-require_user_unprivileged2_head()
-{
-    atf_set "descr" "Helper test case for the t_meta_data test program"
-    atf_set "require.user" "unprivileged"
-}
-require_user_unprivileged2_body()
+require_user3_body()
 {
     :
 }
@@ -482,10 +464,9 @@ atf_init_test_cases()
     atf_add_test_case require_machine
     atf_add_test_case require_progs_body
     atf_add_test_case require_progs_head
-    atf_add_test_case require_user_root
-    atf_add_test_case require_user_root2
-    atf_add_test_case require_user_unprivileged
-    atf_add_test_case require_user_unprivileged2
+    atf_add_test_case require_user
+    atf_add_test_case require_user2
+    atf_add_test_case require_user3
     atf_add_test_case timeout
     atf_add_test_case timeout2
 
