@@ -1,7 +1,7 @@
 #
 # Automated Testing Framework (atf)
 #
-# Copyright (c) 2007 The NetBSD Foundation, Inc.
+# Copyright (c) 2007, 2008 The NetBSD Foundation, Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -12,13 +12,6 @@
 # 2. Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-# 3. All advertising materials mentioning features or use of this
-#    software must display the following acknowledgement:
-#        This product includes software developed by the NetBSD
-#        Foundation, Inc. and its contributors.
-# 4. Neither the name of The NetBSD Foundation nor the names of its
-#    contributors may be used to endorse or promote products derived
-#    from this software without specific prior written permission.
 #
 # THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND
 # CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
@@ -50,8 +43,8 @@ default_body()
 {
     create_files
 
-    for h in h_cpp h_sh; do
-        hp=$(atf_get_srcdir)/${h}
+    for hp in $(get_helpers); do
+        h=${hp##*/}
         cp ${hp} tmp
         atf_check "cd tmp && ./${h} srcdir_exists" 0 ignore ignore
         atf_check "${hp} srcdir_exists" 1 null stderr
@@ -70,10 +63,8 @@ sflag_body()
 {
     create_files
 
-    # XXX Shouldn't have to use absolute pathnames for -s.  Fix this.
-
-    for h in h_cpp h_sh; do
-        hp=$(atf_get_srcdir)/${h}
+    for hp in $(get_helpers); do
+        h=${hp##*/}
         cp ${hp} tmp
         atf_check "cd tmp && ./${h} -s $(pwd)/tmp \
                    srcdir_exists" 0 ignore ignore
@@ -84,10 +75,39 @@ sflag_body()
     done
 }
 
+atf_test_case relative
+relative_head()
+{
+    atf_set "descr" "Checks that passing a relative path through -s" \
+                    "works"
+}
+relative_body()
+{
+    create_files
+
+    for hp in $(get_helpers); do
+        h=${hp##*/}
+        cp ${hp} tmp
+
+        for p in tmp tmp/. ./tmp; do
+            echo "Helper is: ${h}"
+            echo "Using source directory: ${p}"
+
+            atf_check "./tmp/${h} -s ${p} \
+                       srcdir_exists" 0 ignore ignore
+            atf_check "${hp} srcdir_exists" 1 null stderr
+            atf_check 'grep "Cannot.*find.*source.*directory" stderr' \
+                      0 ignore null
+            atf_check "${hp} -s ${p} srcdir_exists" 0 ignore ignore
+        done
+    done
+}
+
 atf_init_test_cases()
 {
     atf_add_test_case default
     atf_add_test_case sflag
+    atf_add_test_case relative
 }
 
 # vim: syntax=sh:expandtab:shiftwidth=4:softtabstop=4
